@@ -1,4 +1,6 @@
-'''This variable is used to format and use dates.
+'''
+@anchor pydoc:grizzly.testdata.variables.date Date
+This variable is used to format and use dates.
 
 ## Format
 
@@ -13,13 +15,13 @@ at the time of access.
 
 ## Example
 
-```gherkin
-And value of variable "AtomicDate.arrival" is "now | format='%Y-%m-%dT%H:%M:%S.000Z', timezone=UTC"
+``` gherkin
+And value for variable "AtomicDate.arrival" is "now | format='%Y-%m-%dT%H:%M:%S.000Z', timezone=UTC"
 ```
 
 This can then be used in a template:
 
-```json
+``` json
 {
     "arrival": "{{ AtomicDate.arrival }}",
     "location": "Port of Shanghai"
@@ -40,8 +42,8 @@ except ImportError:
 
 from grizzly_extras.arguments import split_value, parse_arguments
 
-from ...types import AtomicVariable
 from ...utils import parse_timespan
+from . import AtomicVariable
 
 
 def atomicdate__base_type__(value: str) -> str:
