@@ -9,6 +9,7 @@ from locust.contrib.fasthttp import ResponseContextManager as FastResponseContex
 from locust.env import Environment
 from locust.rpc.protocol import Message
 from locust.runners import WorkerRunner, MasterRunner, LocalRunner
+from grizzly_extras.text import PermutationEnum
 
 __all__ = [
     'Message',
@@ -19,22 +20,33 @@ __all__ = [
 ]
 
 
-class MessageDirection(Enum):
+class MessageDirection(PermutationEnum):
+    __vector__ = (True, True,)
+
     CLIENT_SERVER = 0
     SERVER_CLIENT = 1
 
     @classmethod
     def from_string(cls, value: str) -> 'MessageDirection':
         try:
-            return cls[value.upper()]
+            return cls[value.strip().upper()]
         except KeyError as e:
             raise ValueError(f'"{value.upper()}" is not a valid value of {cls.__name__}') from e
 
 
-class ResponseTarget(Enum):
+class ResponseTarget(PermutationEnum):
+    __vector__ = (False, True,)
+
     METADATA = 0
     PAYLOAD = 1
 
+    @classmethod
+    def from_string(cls, value: str) -> 'ResponseTarget':
+        try:
+            return cls[value.strip().upper()]
+        except KeyError as e:
+            raise ValueError(f'"{value.upper()}" is not a valid value of {cls.__name__}') from e
+
 
 class ResponseAction(Enum):
     VALIDATE = 0
@@ -47,14 +59,16 @@ class ScenarioState(Enum):
     STOPPING = 2
 
 
-class RequestDirection(Enum):
+class RequestDirection(PermutationEnum):
+    __vector__ = (False, True,)
+
     FROM = 'from'
     TO = 'to'
 
     @classmethod
     def from_string(cls, value: str) -> 'RequestDirection':
         try:
-            return cls[value.upper()]
+            return cls[value.strip().upper()]
         except KeyError as e:
             raise ValueError(f'"{value.upper()}" is not a valid value of {cls.__name__}') from e
 
@@ -81,10 +95,18 @@ class RequestMethod(Enum, AdvancedEnum, metaclass=MixedEnumMeta, settings=NoAlia
     RECEIVE = RequestDirection.FROM
     GET = RequestDirection.FROM
 
+    @classmethod
+    def get_vector(cls) -> Tuple[bool, bool]:
+        """
+        aenum.Enum has a definition of __getattr__ that makes it "impossible" to implement vector the same
+        was as for the enums that only inherits enum.Enum.
+        """
+        return (False, True,)
+
     @classmethod
     def from_string(cls, value: str) -> 'RequestMethod':
         try:
-            return RequestMethod[value.upper()]
+            return cls[value.strip().upper()]
         except KeyError as e:
             raise ValueError(f'"{value.upper()}" is not a valid value of {cls.__name__}') from e
 
@@ -103,8 +125,6 @@ class RequestType(Enum, AdvancedEnum, metaclass=MixedEnumMeta, init='alias _weig
     HELLO = ('HELO', None,)
     RECEIVE = ('RECV', None,)
     CONNECT = ('CONN', None,)
-    TIMER = ('TIMR', None,)
-    CONDITIONAL = ('COND', None,)
 
     def __call__(self) -> str:
         return str(self)
@@ -178,14 +198,14 @@ T = TypeVar('T')
 U = TypeVar('U')
 
 
-def bool_typed(value: str) -> bool:
+def bool_type(value: str) -> bool:
     if value in ['True', 'False']:
         return value == 'True'
 
     raise ValueError(f'{value} is not a valid boolean')
 
 
-def int_rounded_float_typed(value: str) -> int:
+def int_rounded_float_type(value: str) -> int:
     return int(round(float(value)))
 
 
